@@ -1,15 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014-2017 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014 -- leonerd@leonerd.org.uk
 
 package Net::Async::Matrix::Utils;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.18_003';
-$VERSION = eval $VERSION;
+our $VERSION = '0.11';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -45,9 +44,7 @@ C<Net::Async::Matrix::Utils> - support utilities for L<Net::Async::Matrix>
 
 =cut
 
-=head2 parse_formatted_message
-
-   $st = parse_formatted_message( $content )
+=head2 $st = parse_formatted_message( $content )
 
 Given the content of a C<m.room.message> event of C<m.text> or C<m.emote>
 type, returns a L<String::Tagged> instance containing the text of the message
@@ -64,15 +61,6 @@ The following formats are recognised:
 This format requires the presence of L<HTML::TreeBuilder> to parse; it will be
 ignored if this module is not available.
 
- HTML              | String::Tagged::Formatting
- ------------------+---------------------------
- <b>, <strong>     | 'bold'
- <i>, <em>         | 'italic'
- <u>               | 'under'
- <strike>          | 'strike'
- <tt>, <code>      | 'monospace'
- <font color="..." | 'fg'
-
 =back
 
 =cut
@@ -109,19 +97,15 @@ sub _traverse_html
 
    my %tags;
    for ( $node->tag ) {
-      ( $_ eq "b" || $_ eq "strong" ) and $tags{bold}++,   last;
-      ( $_ eq "i" || $_ eq "em" )     and $tags{italic}++, last;
-
-      $_ eq "u"      and $tags{under}++,  last;
-      $_ eq "strike" and $tags{strike}++, last;
-
-      ( $_ eq "tt" || $_ eq "code" )  and $tags{monospace}++, last;
+      $_ eq "b" and $tags{bold}++,      last;
+      $_ eq "i" and $tags{italic}++,    last;
+      $_ eq "u" and $tags{underline}++, last;
 
       if( $_ eq "font" ) {
          my %attrs = $node->all_attr;
 
          my $fg = defined $attrs{color} ?
-            eval { Convert::Color::HTML->new( $attrs{color} ) } :
+            eval { Convert::Color::HTML->new( $attrs{color} ) } : 
             undef;
 
          $tags{fg} = $fg if defined $fg;
@@ -139,9 +123,7 @@ sub _traverse_html
    return $ret;
 }
 
-=head2 build_formatted_message
-
-   $content = build_formatted_message( $str )
+=head2 $content = build_formatted_message( $str )
 
 Given a L<String::Tagged::Formatting> instance or plain string, returns a
 content HASH reference encoding the formatting the message. Plain strings are
@@ -155,15 +137,6 @@ formatted content if possible:
 This format is output for formatted messages if L<String::Tagged::HTML> is
 available.
 
- String::Tagged::Formatting | HTML
- ---------------------------+--------------------
- 'bold'                     | <strong>
- 'italic'                   | <em>
- 'under'                    | <u>
- 'strike'                   | <strike>
- 'monospace'                | <code>
- 'fg'                       | <font color="...">
-
 =back
 
 =cut
@@ -174,16 +147,15 @@ sub build_formatted_message
 
    return { body => $str } if !ref $str;
 
-   if( $str->tagnames and CAN_BUILD_HTML ) {
+   if( CAN_BUILD_HTML ) {
       my $html = String::Tagged::HTML->clone( $str,
-         only_tags => [qw( bold italic under strike monospace fg )],
+         only_tags => [qw( bold under italic strike fg )],
          convert_tags => {
-            bold      => "strong",
-            italic    => "em",
-            under     => "u",
-            strike    => "strike",
-            monospace => "code",
-            fg        => sub { font => { color => $_[1]->as_html->name } },
+            bold   => "b",
+            under  => "u",
+            italic => "i",
+            strike => "strike",
+            fg     => sub { font => { color => $_[1]->as_html->name } },
          },
       );
 
@@ -193,9 +165,6 @@ sub build_formatted_message
          formatted_body => $html->as_html,
       };
    }
-   else {
-      return { body => $str->str };
-   }
 }
 
 =head1 AUTHOR
